#
# spec file for package golang
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


# Handle _multibuild magic.
%define flavour %{nil}

# We split the Name: into "realname" and "name_suffix".
%define realname golang-%{provider}-%{project}-%{repo}
%if "%flavour" == ""
%define name_suffix %{nil}
%else
%define name_suffix -%{flavour}
%endif

# MANUAL: Update the git_version and git_revision
%define git_version 872f0a83c98add6cae255c8859e29532febc0039
%define git_short   872f0a83c98a
# How to get the git_revision
# git clone https://github.com/docker/libnetwork.git libnetwork
# cd libnetwork
# git checkout $git_version
# git_revision=r$(git rev-list HEAD | wc -l)
%define git_revision r2726

%global provider        github
%global provider_tld    com
%global project         docker
%global repo            libnetwork
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           %{realname}%{name_suffix}
# NOTE: A while ago, Docker downgraded this dependency on an upgrade, which
#       caused lots of issues when trying to upgrade the RPMs. To fix this, we
#       bumped the version to v0.7.0.1+... which RPM saw as an upgrade.
#       Unfortunately subsequent upgrades have yet to bump the other version
#       components, so we need to keep the '.1' even though it isn't
#       technically correct. Hopefully we will be able to remove it eventually.
Version:        0.7.0.1+git%{git_revision}_%{git_short}
Release:        lp151.2.3.1
Summary:        Docker Networking
License:        Apache-2.0
Group:          Development/Languages/Golang
Url:            http://github.com/docker/libnetwork
Source0:        %{repo}-git.%{git_version}.tar.xz
Source1:        %{realname}-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.10
ExcludeArch:    s390
# KUBIC-SPECIFIC: This was required when upgrading from the original kubic
#                 packaging, when everything was renamed to -kubic. It also is
#                 used to ensure that nothing complains too much when using
#                 -kubic packages. Hopfully it can be removed one day.
%if "%flavour" == "kubic"
# Conflict with the non-Kubic package, and provide equivalent
Conflicts:      golang-%{provider}-%{project}-%{repo}
Provides:       golang-%{provider}-%{project}-%{repo} = %{version}
# Disable leap based builds for kubic flavor (bsc#1121412)
%if 0%{?suse_version} == 1500 && 0%{?is_opensuse}
ExclusiveArch:  do_not_build
%endif
%endif
%{go_provides}

%description
Libnetwork provides a native Go implementation for connecting containers

The goal of libnetwork is to deliver a robust Container Network Model that
provides a consistent programming interface and the required network
abstractions for applications.

%package -n docker-libnetwork%{name_suffix}
Summary:        Docker Networking
Group:          System/Management
AutoReqProv:    Off
Conflicts:      docker < 17.09.0_ce
Provides:       fix_bsc_1057743
# We provide a git revision so that Docker can require it properly.
Provides:       docker-libnetwork%{name_suffix}-git = %{git_version}
# KUBIC-SPECIFIC: This was required when upgrading from the original kubic
#                 packaging, when everything was renamed to -kubic. It also is
#                 used to ensure that nothing complains too much when using
#                 -kubic packages. Hopfully it can be removed one day.
%if "%flavour" == "kubic"
# Conflict with non-kubic package, and provide equivalent
Conflicts:      docker-libnetwork-git
Provides:       docker-libnetwork-git = %{version}
%endif

%description -n docker-libnetwork%{name_suffix}
The docker-proxy binary used by Docker that provides Docker with libnetwork
support.


%prep
%setup -q -n %{repo}-git.%{git_version}

%build
%goprep %{import_path}
export CGO_ENABLED=0
%gobuild -buildmode=default cmd/proxy

%install
%{goinstall}
mv %{buildroot}/%{_bindir}/proxy %{buildroot}/%{_bindir}/docker-proxy
%{gosrc}
%{gofilelist}

%fdupes %{buildroot}/%{_prefix}

%files -f file.lst
%defattr(-,root,root,-)
%doc README.md MAINTAINERS
%license LICENSE

%files -n docker-libnetwork%{name_suffix}
%defattr(-,root,root,-)
%{_bindir}/docker-proxy

%changelog
* Mon May  6 2019 asarai@suse.com
- Update to version git.872f0a83c98add6cae255c8859e29532febc0039 which is
  required for Docker v18.09.6-ce.
  * Pick a random host port if the user does not specify a host port.
  * Cleanup the cluster provider when the agent is closed
  * Adding error log if peerAdd fails
  * Adding synchronization to endpoint addition/deletion to prevent network connectivity issue
  * Revert "Merge pull request #2286 from thaJeztah/18.09_backport_iptables_legacy"
  * Bump Go to 1.10.7
  * Fix possible nil pointer exception
  * Fix gosimple
  * account for removal of configs.HookState
* Fri May  3 2019 Aleksa Sarai <asarai@suse.com>
- Update to version git.4725f2163fb214a6312f3beae5991f838ec36326 which is
  required for Docker v18.09.5-ce: bsc#1128376 boo#1134068
  * Revert "Merge pull request #2286 from thaJeztah/18.09_backport_iptables_legacy"
  * Bump Go to 1.10.7
  * Fix possible nil pointer exception
  * Fix gosimple
  * account for removal of configs.HookState
  * vndr runc 96ec217
  * Update golint tool
  * debian has iptables-legacy and iptables-nft now
  * Make DSR an overlay-specific driver "option"
  * Set east-west load balancing to use direct routing
* Tue Feb  5 2019 Aleksa Sarai <asarai@suse.com>
- Update to version git.2cfbf9b1f98162a55829a21cc603c76072a75382 which is
  required for Docker v18.09.1-ce bsc#1124308:
  * account for removal of configs.HookState
  * vndr runc 96ec217
  * Update golint tool
  * debian has iptables-legacy and iptables-nft now
  * Make DSR an overlay-specific driver "option"
  * Set east-west load balancing to use direct routing
  * Add getter function for Default Address Pools
  * Global Default Address Pool support
* Fri Jan 11 2019 Sascha Grunert <sgrunert@suse.com>
- Disable leap based builds for kubic flavor. bsc#1121412
* Wed Dec 19 2018 clee@suse.com
- Update go requirements to >= go1.10 to fix
  * bsc#1118897 CVE-2018-16873
    go#29230 cmd/go: remote command execution during "go get -u"
  * bsc#1118898 CVE-2018-16874
    go#29231 cmd/go: directory traversal in "go get" via curly braces in import paths
  * bsc#1118899 CVE-2018-16875
* Thu Nov 29 2018 Aleksa Sarai <asarai@suse.com>
- Update to version git.6da50d1978302f04c3e2089e29112ea24812f05b which is
  required for Docker v18.09.0-ce.
  * Make DSR an overlay-specific driver "option"
  * Set east-west load balancing to use direct routing
  * Add getter function for Default Address Pools
  * Global Default Address Pool support
  * Move SSD image to docker
  * Give LB sandboxes predictable names
  * Fix handling of the resolv.conf
  * Create internal directory
* Thu Aug 16 2018 asarai@suse.com
- Merge -kubic packages back into the main Virtualization:containers packages.
  This is done using _multibuild to add a "kubic" flavour, which is then used
  to conditionally compile patches and other kubic-specific features.
  bsc#1105000
* Wed Jul 25 2018 asarai@suse.com
- Switch to Go 1.10 for build.
- Upgrade to version 3ac297bc7fd0afec9051bbb47024c9bc1d75bf5b which is requried
  by the Docker v18.06.0-ce upgrade. bsc#1102522 bsc#1113313
  * Use fmt precision to limit string length
  * Fix error handling about bridgeSetup
  * ipam: Test rejection of overlapping pool requests
  * ipam, types: Expand documentation
  * CircleCI use latest image
  * Optimize networkDB queue
  * Enhance testing infra
  * Allows to set generic knobs on the Sandbox
* Wed Jun 13 2018 dcassany@suse.com
- Make use of %%license macro
* Mon Feb 12 2018 rbrown@suse.com
- Add ${version} to equivalent non-kubic package provides
* Thu Feb  8 2018 rbrown@suse.com
- Add Provides for equivalent non-kubic packages
* Thu Feb  1 2018 ro@suse.de
- do not build on s390, only on s390x (no go on s390)
* Wed Jan 31 2018 vrothberg@suse.com
- Make it conflict with the non-Kubic package to avoid a file conflict in
  Factory.
* Mon Jan 29 2018 vrothberg@suse.com
- Correct conflict with docker < 17.09.0_ce to avoid a file conflict on
  docker-proxy.
* Mon Dec 11 2017 asarai@suse.com
- Update to version git.7b2b1feb1de4817d522cc372af149ff48d25028e (required by
  Docker v17.09.1_ce):
  * proxy: clean up code (addendum to #1598)
  * Use vndr for managing libnetwork dependencies
  * carry docker/docker #29564
  * Godep update for docker plugingetter pkg
  * return an error on overlay subnet is overlapped with hosts
  * Prioritize nw endpoint which can provide both v4 and v6 connectivity
  * proxy: fix an issue about half-closing net.TCPConn after io.Copy()
  * Add embedded DNS server support for host loopback resolver
  * Fix fqdn hostnames not added to /etc/hosts
* Wed Oct 18 2017 asarai@suse.com
- Update to version 0.7.0+git4a242dba7739 (required by Docker v17.07_ce):
  * optimize the rebroadcast for failure case
  * Revert "Fixes bug that mistook gw6 for gw."
  * Revert "Funnel peerAdd and peerDelete in a channel"
  * Avoid peerUpdate logic in swarm mode
  * Fixes bug which makes restoring endpoint mess
  * Revert "Avoid peerUpdate logic in swarm mode"
  * Funnel peerAdd and peerDelete in a channel
  * PeerInit for the sandbox init
  * PeerDbDelete was passing the wrong field
  * Lock goroutine to OS thread while changing NS
- Fix up _service file and versioning to actually be somewhat sane.
* Thu Sep 28 2017 thipp@suse.de
- always use -buildmode=default
* Wed Sep 27 2017 jmassaguerpla@suse.com
- fix bsc#1057743: this package provides the fix for this issue.
  I could not change the version of the libnetwork because that is
  attached to the upstream commits, and I can't control the release
  number, so I added this "symbol", fix_bsc_1057743 which is required
  by the latest docker package.
* Tue May  2 2017 jmassaguerpla@suse.com
- fix golang requirements
* Thu Apr 13 2017 opensuse-packaging@opensuse.org
- Update to version 0.0.0+git20170119.7b2b1fe:
  * Separate pool parsing from pool auto-allocation
  * Handle containers with different network drivers
  * Remove driver endpoints on network deleting
  * Update loadDriver to use pluginv2.
  * validate network and endpoint name more strictly
  * overlay driver support for Solaris Signed-off-by: Puneet Pruthi <puneetpruthi@gmail.com>
  * Updated vagrant box, ubuntu/vivid64 was remove from atlas.hasicorp.com
  * Use monotonic clock for reaping networkDB entries
  * Reap failed nodes after 24 hours
  * Do not update hosts file with internal networks endpoint IP
  * Fix issue for `--fixed-cidr` when bridge has multiple addresses
  * Add sandbox API for task insertion to service LB and service discovery
  * Enable ping for service vip address
  * Block non exposed port traffic on ingress nw interfaces
  * Fix some typos
  * Respect icc option for internal networks
  * fix nits in comments and log
  * Modify the serial number from 1 to 9
  * Allow concurrent calls to agentClose
  * Fixing incorrect resovler error message shown on daemon startup
  * Add NetworkDB API to fetch the per network peer (gossip cluster) list
  * Vendoring hcsshim to pick overlay changes
  * Windows overlay driver support
  * Change vxlan-id start-idx to 4096
  * If enabling ip forwarding set the default forward policy to drop
  * Register remote network driver on Windows.
  * update reapNode interval
  * remove unused mConfig
  * Check subnet overlap when programming of sandbox interface
  * Refactoring logrus import and formatting This fix tries to fix logrus formatting by removing `f` from `logrus.[Error|Warn|Debug|Fatal|Panic|Info]f` when formatting string is not present. Also fix import name to use original project name 'logrus' instead of 'log'
  * Default GW support for overlay networks
  * Support attachable in network.
  * Update libkv @1d84310
  * Respect auto allocation for --ipv6
  * Increase timeout for local store client
  * Add GetIDInRange API in idm package
  * IDM need not be bound by default vxlan-id start index
  * fix unsafe acces on arm
  * Fix new golint reported errors
  * Fix bug in DeleteNeighbor
  * Add a nil check for sandbox.osSbox
  * Update netlink @17ea11b
  * Set a timeout on the netlink handle sockets
  * Allow spaces in network names
  * Separate service LB & SD from network plumbing
  * Fix bug in needDefaultGW()
  * Revert "Enable ping for service vip address"
  * Add a ICMP reply rule for service VIP
  * Fix bug in link-local unmarshalling
  * Refactoring logrus import and formatting Fix import name to use original project name 'logrus' instead of 'log' Removing `f` from `logrus.Debugf` when formatting string is not present.
  * Serialize embedded resolver Start and Stop
  * Remove unnecessary string formats
  * Fix xtables_lock message probe
  * Control IPv6 on container's interface
  * Create vxlan-id space from 0 instead of starting from 1
  * Fixed misspelling
  * Fix a bug in idm.GetIDInRange()
  * Fix incorrect debug message
  * Add missing locks in agent and service code
  * networkdb: Properly format memberlist logs
  * fix review comments
  * Check for node's presence in networkDB's node map before accessing.
  * Correct regexp to match v6 addresses with zone ID
  * Fix fqdn hostnames not added to /etc/hosts
  * Handling the new experimental daemon flag
  * Handle the case of registering active plugins during remote init
  * Internal interface to differentiate built-in drivers from remote
  * drvregistry to allow overriding plugin
  * Defer PTR queries to external servers based on A/AAAA response
  * Add embedded DNS server support for host loopback resolver
  * proxy: fix an issue about half-closing net.TCPConn after io.Copy()
  * make network connect error message readable
  * fix nits in comments
  * fix typos
  * docs/remote.md: Remove unnecessary backquote
  * ResolveName should return copy of IPs
  * Prioritize nw endpoint which can provide both v4 and v6 connectivity
  * fix json
  * Updating Godeps to pull in plugingetter dependancy
  * Make use of GetAllManagedPluginsForCap to avoid loading v1-plugins
  * return an error on overlay subnet is overlapped with hosts
  * Godep update for docker plugingetter pkg
  * carry docker/docker #29564
  * Use vndr for managing libnetwork dependencies
  * proxy: clean up code (addendum to #1598)
* Thu Apr 13 2017 opensuse-packaging@opensuse.org
- Update to version 0.0.0+git20161019.0f53435:
  * fix race in serializing sandbox to string
  * Run API check to assert xfrm modules
  * Check for presence before installing forward rules
  * add Created to NetworkInfo
  * Avoid controller/service lock AB/BA situation
  * libnetwork support for Solaris Signed-off-by: Puneet Pruthi <puneetpruthi@gmail.com>
  * Fix map access race in populatedEndpoints
  * Do not use logrus for proxy
* Wed Apr 12 2017 jmassaguerpla@suse.com
- make sure we use go 1.7
* Mon Mar 13 2017 jmassaguerpla@suse.com
- rename lintrc to %%{name}-lintrc
* Fri Feb 24 2017 jmassaguerpla@suse.com
- add the docker-libnetwork package which installs docker-proxy
* Wed Feb 22 2017 thipp@suse.de
- Fix build
* Mon Feb 20 2017 jmassaguerpla@suse.com
- initial import
